@@ -15,6 +15,7 @@ from .Tooltip import Tooltip
 from .GlobalSearchBar import GlobalSearchBar
 from .MaterialsInput import MaterialsInput
 from .Select import Select
+from .Dropdown import Dropdown
 from .NavbarDropdown import NavbarDropdown
 from .Scrollspy import Scrollspy
 from .PeriodicContext import PeriodicContext
@@ -47,6 +48,7 @@ __all__ = [
     "GlobalSearchBar",
     "MaterialsInput",
     "Select",
+    "Dropdown",
     "NavbarDropdown",
     "Scrollspy",
     "PeriodicContext",
